==> haskell-inspection-testing-0.5.0.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 inspection-testing
version:              0.5.0.3
visibility:           public
id:                   inspection-testing-0.5.0.3-2OudPLUZJQj32eoiHRYWC6
key:                  inspection-testing-0.5.0.3-2OudPLUZJQj32eoiHRYWC6
license:              MIT
copyright:            2017 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             https://github.com/nomeata/inspection-testing
synopsis:             GHC plugin to do inspection testing
description:
    Some carefully crafted libraries make promises to their
    users beyond functionality and performance.

    Examples are: Fusion libraries promise intermediate data
    structures to be eliminated. Generic programming libraries promise
    that the generic implementation is identical to the
    hand-written one. Some libraries may promise allocation-free
    or branch-free code.

    Conventionally, the modus operandi in all these cases is
    that the library author manually inspects the (intermediate or
    final) code produced by the compiler. This is not only
    tedious, but makes it very likely that some change, either
    in the library itself or the surrounding eco-system,
    breaks the library’s promised without anyone noticing.

    This package provides a disciplined way of specifying such
    properties, and have them checked by the compiler. This way,
    this checking can be part of the ususal development cycle
    and regressions caught early.

    See the documentation in "Test.Inspection" or the project
    webpage for more examples and more information.

category:             Testing, Compiler Plugin
abi:                  7ba099ab78342496dcdd249179076bcc
exposed:              True
exposed-modules:
    Test.Inspection Test.Inspection.Core Test.Inspection.Plugin

import-dirs:          /usr/lib/ghc-9.2.8/site-local/inspection-testing-0.5.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/inspection-testing-0.5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-inspection-testing
hs-libraries:         HSinspection-testing-0.5.0.3-2OudPLUZJQj32eoiHRYWC6
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-9.2.8 mtl-2.2.2
    template-haskell-2.18.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-inspection-testing/html/inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-inspection-testing-0.5-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 inspection-testing
version:              0.5
visibility:           public
id:                   inspection-testing-0.5-E1OaW6tRISQ8DDKCsoVgbM
key:                  inspection-testing-0.5-E1OaW6tRISQ8DDKCsoVgbM
license:              MIT
copyright:            2017 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             https://github.com/nomeata/inspection-testing
synopsis:             GHC plugin to do inspection testing
description:
    Some carefully crafted libraries make promises to their
    users beyond functionality and performance.

    Examples are: Fusion libraries promise intermediate data
    structures to be eliminated. Generic programming libraries promise
    that the generic implementation is identical to the
    hand-written one. Some libraries may promise allocation-free
    or branch-free code.

    Conventionally, the modus operandi in all these cases is
    that the library author manually inspects the (intermediate or
    final) code produced by the compiler. This is not only
    tedious, but makes it very likely that some change, either
    in the library itself or the surrounding eco-system,
    breaks the library’s promised without anyone noticing.

    This package provides a disciplined way of specifying such
    properties, and have them checked by the compiler. This way,
    this checking can be part of the ususal development cycle
    and regressions caught early.

    See the documentation in "Test.Inspection" or the project
    webpage for more examples and more information.

category:             Testing, Compiler Plugin
abi:                  ed24f1ef6771ad7afa9bead034880a38
exposed:              True
exposed-modules:
    Test.Inspection Test.Inspection.Core Test.Inspection.Plugin

import-dirs:          /usr/lib/ghc-9.0.2/site-local/inspection-testing-0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/inspection-testing-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-inspection-testing
hs-libraries:         HSinspection-testing-0.5-E1OaW6tRISQ8DDKCsoVgbM
depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-9.0.2 mtl-2.2.2
    template-haskell-2.17.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-inspection-testing/html/inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-inspection-testing/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
